<?php

require_once 'base/GepFluxoencasoliEntityBase.php';

/**
 * This class has been auto-generated by Setforms
 *
 * @package Entity
 * @author  Setforms
 */
class GepFluxoencasoliEntity extends GepFluxoencasoliEntityBase
{


    const IDATIVO = 'S';
    CONST SEM_REGISTRO = 0;


    /**     ok
     * Gera novo codigo do fluxo de encaminhamento da solicitacao.
     *
     * @param integer $nrorg N?mero da Organizacao.
     *
     * @return Ambigous <number, number>
     */
    public static function novoCodigoGepFluxoencasoli($nrorg){
        $codigo = Novocodigo::geraCodigo($nrorg, 'GEP_FLUXOENCASOLI', 10);
        return $codigo;
    }


    /**       ok
     * Insere registro do fluxo de encaminhamento de uma determinada solicitacao.
     *
     * @param integer $codigo         Novo codigo.
     * @param integer $solicitacao    Numero da solicitacao.
     * @param integer $parceiro       Codigo do parceiro.
     * @param integer $perfil         Perfil de acesso.
     * @param integer $tiposoli_ant   Numero do tipo da solicitacao anterior.
     * @param integer $situacao_ant   Numero da situacao anterior.
     * @param integer $tiposoli_prox  Numero do proximo tipo da solicitacao.
     * @param integer $situacao_prox  Numero da proxima situacao.
     * @param integer $nrmotivo_fluxo Numero do motivo.
     * @param string  $txt_observacao Texto de observacao do parceiro.
     * @param string  $txt_log        Texto de log.
     * @param integer $nrorg          Numero da Organizacao.
     * @param date    $data           Data de insercao.
     * @param integer $operador       Codigo do operador que inseriu.
     *
     * @return boolean
     */
    public function insereFluxoencasoli(
        $codigo, $solicitacao, $parceiro, $perfil, $tiposoli_ant, $situacao_ant,
        $tiposoli_prox, $situacao_prox, $nrmotivo_fluxo, $txt_observacao,
        $txt_log, $nrorg, $data, $operador
    ){
        try {
            $obj = new self();

            $obj->setNrfluxoencasoli($codigo);
            $obj->setNrsolicitacao($solicitacao);
            $obj->setNrparcoperresp($parceiro);
            $obj->setNrperfilacessoresp($perfil);
            $obj->setNrtiposoliante($tiposoli_ant);
            $obj->setNrsituacaoante($situacao_ant);
            $obj->setNrtiposoliprox($tiposoli_prox);
            $obj->setNrsituacaoprox($situacao_prox);
            $obj->setNrmotivofluxo($nrmotivo_fluxo);
            $obj->setTxobservfluxosoli($txt_observacao);
            $obj->setTxlogfluxosoli($txt_log);
            $obj->setNrorg($nrorg);
            $obj->setIdativo(self::IDATIVO);
            $obj->setDtinclusao($data);
            $obj->setDtultatu($data);
            $obj->setNrorginclusao($nrorg);
            $obj->setCdoperinclusao($operador);
            $obj->setNrorgultatu($nrorg);
            $obj->setCdoperultatu($operador);
            $obj->persist();

            return true;
        } catch (Exception $e) {
            showClassError($e, __FUNCTION__, __LINE__);
            return false;
        }
    }


    /**
     * Atualiza os campos de motivo, observa??o e campos de AUDT de um fluxo de encaminhamento.
     *
     * @param integer $nrorg             N?mero da Organiza??o.
     * @param integer $nrencaminhamento  C?digo do fluxo de encaminhamento.
     * @param integer $solicitacao       N?mero da Solicita??o.
     * @param date    $dtinclusao        Data da inclus?o.
     * @param integer $motivo            N?mero do motivo.
     * @param string  $observacao        Texto de Observa??o.
     * @param date    $dtatualiza        Data da atualiza??o.
     * @param integer $operador_atualiza Operador respons?vel pela atualiza??o.
     *
     * @return boolean
     */
    public function atualizaFluxoEncaminhamento(
    $nrorg, $nrencaminhamento, $solicitacao, date $dtinclusao,
    $motivo, $observacao, date $dtatualiza, $operador_atualiza
    ){
        $lista_fluxo = GepFluxoencasoli::getObjectsByWhere(
            'NRORG = ? AND NRSOLICITACAO = ? AND DTINCLUSAO = ? AND NRFLUXOENCASOLI = ?',
            array(
             $nrorg,
             $solicitacao,
             $dtinclusao,
             $nrencaminhamento,
            )
        );

        foreach ($lista_fluxo as $registro) {
            $registro->setNrmotivofluxo($motivo);
            $registro->setTxobservfluxosoli($observacao);
            $registro->setDtultatu($dtatualiza);
            $registro->setCdoperultatu($operador_atualiza);
            $registro->persist();
        }

        return true;
    }


    /**
     * Consulta os dados de um fluxo de encaminhamento de uma determinada solicita??o.
     *
     * @param integer $nrorg       N?o da Organiza??o.
     * @param integer $solicitacao N?o da Solicita??o.
     *
     * @throws Exception Se n?houver registro.
     *
     * @return GepFluxoencasoliEntity
     */
    public function consultaDadosEncaminhamento($nrorg, $solicitacao){
        $dados = GepFluxoencasoli::consultaDadosEncaminhamento($nrorg, $solicitacao);

        if (is_array($dados) === true) {
            return $dados;
        }

        throw new Exception(
            'GepFluxoencasoliEntity: Nao ha encaminhamentos para esta solicitacao!',
            self::SEM_REGISTRO
        );
    }


    /**
     * Consulta o ultimo dado de um fluxo de encaminhamento de uma determinada solicita??o.
     *
     * @param integer $nrorg       N?o da Organiza??o.
     * @param integer $solicitacao N?o da Solicita??o.
     *
     * @throws Exception Se n?houver registro.
     *
     * @return GepFluxoencasoliEntity
     */
    public function consultaUltimoDadoEncaminhamento($nrorg, $solicitacao){
        $dados = GepFluxoencasoli::consultaUltimoDadoEncaminhamento($nrorg, $solicitacao);

        if (is_array($dados) === true) {
            return $dados;
        }

        throw new Exception(
            'GepFluxoencasoliEntity: Nao ha encaminhamentos para esta solicitacao!',
            self::SEM_REGISTRO
        );
    }


    /**        ok
     * Consulta o fluxo da solicitacao.
     * 
     * @param integer $nrorg Numero da organizacao.
     * 
     * @return string
     */
    public static function consultaFluxoSoli($nrorg){
        $sql = GepFluxoencasoli::sqlFluxoSoli($nrorg);
        return $sql;
    }


}